Documentation
¶
Overview ¶
Package multiproject handles cross-project memory linking and global entity resolution.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CrossProjectSearch ¶
CrossProjectSearch searches for nodes matching a query across multiple stores.
func LinkProjects ¶
LinkProjects creates a cross-project edge between two nodes in different stores. The edge is stored in the global store (dst) as a relates_to edge.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.